pub fn builtin(name: &str) -> Option<&'static BuiltinSchema>Expand description
The builtin type name describes itself with, if there is one.
pub fn builtin(name: &str) -> Option<&'static BuiltinSchema>The builtin type name describes itself with, if there is one.